@@ -123,10 +123,11 @@ public:
         }
 
         QString clashingKeys;
-        Q_FOREACH (const QKeySequence &seq, shortcuts.keys()) {
-            Q_FOREACH (const KGlobalShortcutInfo &info, shortcuts[seq]) {
+        for (auto it = shortcuts.begin(), end = shortcuts.end(); it != end; ++it) {
+            const auto seqAsString = it.key().toString();
+            for (const KGlobalShortcutInfo &info : it.value()) {
                 clashingKeys += i18n("Shortcut '%1' in Application %2 for action %3\n",
-                                     seq.toString(),
+                                     seqAsString,
                                      info.componentFriendlyName(),
                                      info.friendlyName());
             }
@@ -143,7 +144,7 @@ public:
         QString title = i18ncp("%1 is the number of shortcuts with which there is a conflict",
                                "Conflict with Registered Global Shortcut", "Conflict with Registered Global Shortcuts", hashSize);
 
-        return KMessageBox::warningContinueCancel(parent, message, title, KGuiItem(i18n("Reassign")))
+        return KMessageBox::warningContinueCancel(parent, message, title, KGuiItem(i18nc("@action:button", "Reassign")))
                == KMessageBox::Continue;
     }
 #endif
@@ -215,7 +216,7 @@ bool KKeySequenceWidgetPrivate::stealShortcuts(
     QString title = i18ncp("%1 is the number of conflicts", "Shortcut Conflict", "Shortcut Conflicts", listSize);
 
     QString conflictingShortcuts;
-    Q_FOREACH (const QAction *action, actions) {
+    for (const QAction *action : actions) {
         conflictingShortcuts += i18n("Shortcut '%1' for action '%2'\n",
                                      action->shortcut().toString(QKeySequence::NativeText),
                                      KLocalizedString::removeAcceleratorMarker(action->text()));
@@ -231,7 +232,7 @@ bool KKeySequenceWidgetPrivate::stealShortcuts(
                              seq.toString(QKeySequence::NativeText),
                              conflictingShortcuts);
 
-    if (KMessageBox::warningContinueCancel(q, message, title, KGuiItem(i18n("Reassign"))) != KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancel(q, message, title, KGuiItem(i18nc("@action:button", "Reassign"))) != KMessageBox::Continue) {
         return false;
     }
 
@@ -240,7 +241,7 @@ bool KKeySequenceWidgetPrivate::stealShortcuts(
 
 void KKeySequenceWidgetPrivate::wontStealShortcut(QAction *item, const QKeySequence &seq)
 {
-    QString title(i18n("Shortcut conflict"));
+    QString title(i18nc("@title:window", "Shortcut conflict"));
     QString msg(i18n("<qt>The '%1' key combination is already used by the <b>%2</b> action.<br>"
                      "Please select a different one.</qt>", seq.toString(QKeySequence::NativeText),
                      KLocalizedString::removeAcceleratorMarker(item->text())));
@@ -271,7 +272,7 @@ void KKeySequenceWidgetPrivate::init()
     keyButton = new KKeySequenceButton(this, q);
     keyButton->setFocusPolicy(Qt::StrongFocus);
     keyButton->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
-    keyButton->setToolTip(i18n("Click on the button, then enter the shortcut like you would in the program.\nExample for Ctrl+A: hold the Ctrl key and press A."));
+    keyButton->setToolTip(i18nc("@info:tooltip", "Click on the button, then enter the shortcut like you would in the program.\nExample for Ctrl+A: hold the Ctrl key and press A."));
     layout->addWidget(keyButton);
 
     clearButton = new QToolButton(q);
@@ -339,7 +340,7 @@ void KKeySequenceWidget::setClearButtonShown(bool show)
     d->clearButton->setVisible(show);
 }
 
-#ifndef KXMLGUI_NO_DEPRECATED
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(4, 1)
 void KKeySequenceWidget::setCheckActionList(const QList<QAction *> &checkList) // deprecated
 {
     d->checkList = checkList;
@@ -389,7 +390,7 @@ void KKeySequenceWidget::applyStealShortcut()
 {
     QSet<KActionCollection *> changedCollections;
 
-    Q_FOREACH (QAction *stealAction, d->stealActions) {
+    for (QAction *stealAction : qAsConst(d->stealActions)) {
 
         // Stealing a shortcut means setting it to an empty one.
         stealAction->setShortcuts(QList<QKeySequence>());
@@ -397,7 +398,7 @@ void KKeySequenceWidget::applyStealShortcut()
         // The following code will find the action we are about to
         // steal from and save it's actioncollection.
         KActionCollection *parentCollection = nullptr;
-        foreach (KActionCollection *collection, d->checkActionCollections) {
+        for (KActionCollection *collection : qAsConst(d->checkActionCollections)) {
             if (collection->actions().contains(stealAction)) {
                 parentCollection = collection;
                 break;
@@ -410,7 +411,7 @@ void KKeySequenceWidget::applyStealShortcut()
         }
     }
 
-    Q_FOREACH (KActionCollection *col, changedCollections) {
+    for (KActionCollection *col : qAsConst(changedCollections)) {
         col->writeSettings();
     }
 
@@ -515,7 +516,7 @@ static bool shortcutsConflictWith(const QList<QKeySequence> &shortcuts, const QK
         return false;
     }
 
-    foreach (const QKeySequence &sequence, shortcuts) {
+    for (const QKeySequence &sequence : shortcuts) {
         if (sequence.isEmpty()) {
             continue;
         }
@@ -544,7 +545,7 @@ bool KKeySequenceWidgetPrivate::conflictWithLocalShortcuts(const QKeySequence &k
     // removed from the collection again.
     QList<QAction *> allActions;
     allActions += checkList;
-    foreach (KActionCollection *collection, checkActionCollections) {
+    for (KActionCollection *collection : qAsConst(checkActionCollections)) {
         allActions += collection->actions();
     }
 
@@ -568,7 +569,7 @@ bool KKeySequenceWidgetPrivate::conflictWithLocalShortcuts(const QKeySequence &k
     QList<QAction *> conflictingActions;
 
     //find conflicting shortcuts with existing actions
-    foreach (QAction *qaction, allActions) {
+    for (QAction *qaction : qAsConst(allActions)) {
         if (shortcutsConflictWith(qaction->shortcuts(), keySequence)) {
             // A conflict with a KAction. If that action is configurable
             // ask the user what to do. If not reject this keySequence.
@@ -590,7 +591,7 @@ bool KKeySequenceWidgetPrivate::conflictWithLocalShortcuts(const QKeySequence &k
         stealActions = conflictingActions;
         // Announce that the user
         // agreed
-        Q_FOREACH (QAction *stealAction, stealActions) {
+        for (QAction *stealAction : qAsConst(stealActions)) {
             emit q->stealShortcut(
                 keySequence,
                 stealAction);
@@ -616,13 +617,13 @@ bool KKeySequenceWidgetPrivate::conflictWithStandardShortcuts(const QKeySequence
 
 bool KKeySequenceWidgetPrivate::stealStandardShortcut(KStandardShortcut::StandardShortcut std, const QKeySequence &seq)
 {
-    QString title = i18n("Conflict with Standard Application Shortcut");
+    QString title = i18nc("@title:window", "Conflict with Standard Application Shortcut");
     QString message = i18n("The '%1' key combination is also used for the standard action "
                            "\"%2\" that some applications use.\n"
                            "Do you really want to use it as a global shortcut as well?",
                            seq.toString(QKeySequence::NativeText), KStandardShortcut::label(std));
 
-    if (KMessageBox::warningContinueCancel(q, message, title, KGuiItem(i18n("Reassign"))) != KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancel(q, message, title, KGuiItem(i18nc("@action:button", "Reassign"))) != KMessageBox::Continue) {
         return false;
     }
     return true;
@@ -718,7 +719,7 @@ void KKeySequenceButton::keyPressEvent(QKeyEvent *e)
         // and QKeySequence.toString() will also yield a garbage string.
         KMessageBox::sorry(this,
                            i18n("The key you just pressed is not supported by Qt."),
-                           i18n("Unsupported Key"));
+                           i18nc("@title:window", "Unsupported Key"));
         d->cancelRecording();
         return;
     }
