@@ -22,7 +22,6 @@
 
 #include <stdio.h>
 
-#include <QDebug>
 #include <QSslSocket>
 #include <QHostInfo>
 
@@ -90,23 +89,23 @@ void SMTP::setSenderAddress(const QString &sender)
     if (index == -1) {
         return;
     }
-    senderAddress = senderAddress.mid(index + 1);
+    senderAddress.remove(0, index + 1);
     index =  senderAddress.indexOf(QLatin1Char('>'));
     if (index != -1) {
-        senderAddress = senderAddress.left(index);
+        senderAddress.truncate(index);
     }
     senderAddress = senderAddress.simplified();
     while (1) {
         index =  senderAddress.indexOf(QLatin1Char(' '));
         if (index != -1) {
-            senderAddress = senderAddress.mid(index + 1);    // take one side
+            senderAddress.remove(0, index + 1);    // take one side
         } else {
             break;
         }
     }
     index = senderAddress.indexOf(QLatin1Char('@'));
     if (index == -1) {
-        senderAddress.append(QStringLiteral("@localhost"));    // won't go through without a local mail system
+        senderAddress.append(QLatin1String("@localhost"));    // won't go through without a local mail system
     }
 
 }
