@@ -130,10 +130,11 @@ void KShortcutsEditor::addCollection(KActionCollection *collection, const QStrin
     QSet<QAction *> actionsSeen;
 
     // Add all categories in their own subtree below the collections root node
-    QList<KActionCategory *> categories = collection->findChildren<KActionCategory *>();
-    foreach (KActionCategory *category, categories) {
+    const QList<KActionCategory *> categories = collection->findChildren<KActionCategory *>();
+    for (KActionCategory *category : categories) {
         hier[KShortcutsEditorPrivate::Action] = d->findOrMakeItem(hier[KShortcutsEditorPrivate::Program], category->text());
-        foreach (QAction *action, category->actions()) {
+        const auto categoryActions = category->actions();
+        for (QAction *action : categoryActions) {
             // Set a marker that we have seen this action
             actionsSeen.insert(action);
             d->addAction(action, hier, KShortcutsEditorPrivate::Action);
@@ -142,7 +143,8 @@ void KShortcutsEditor::addCollection(KActionCollection *collection, const QStrin
 
     // The rest of the shortcuts is added as a direct shild of the action
     // collections root node
-    foreach (QAction *action, collection->actions()) {
+    const auto collectionActions = collection->actions();
+    for (QAction *action : collectionActions) {
         if (actionsSeen.contains(action)) {
             continue;
         }
@@ -164,7 +166,7 @@ void KShortcutsEditor::clearConfiguration()
     d->clearConfiguration();
 }
 
-#ifndef KXMLGUI_NO_DEPRECATED
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
 void KShortcutsEditor::importConfiguration(KConfig *config)
 {
     d->importConfiguration(config);
@@ -176,7 +178,7 @@ void KShortcutsEditor::importConfiguration(KConfigBase *config)
     d->importConfiguration(config);
 }
 
-#ifndef KXMLGUI_NO_DEPRECATED
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
 void KShortcutsEditor::exportConfiguration(KConfig *config) const
 {
     exportConfiguration(static_cast<KConfigBase *>(config));
@@ -193,14 +195,14 @@ void KShortcutsEditor::exportConfiguration(KConfigBase *config) const
     if (d->actionTypes & KShortcutsEditor::GlobalAction) {
         QString groupName(QStringLiteral("Global Shortcuts"));
         KConfigGroup group(config, groupName);
-        foreach (KActionCollection *collection, d->actionCollections) {
+        for (KActionCollection *collection : qAsConst(d->actionCollections)) {
             collection->exportGlobalShortcuts(&group, true);
         }
     }
     if (d->actionTypes & ~KShortcutsEditor::GlobalAction) {
         QString groupName(QStringLiteral("Shortcuts"));
         KConfigGroup group(config, groupName);
-        foreach (KActionCollection *collection, d->actionCollections) {
+        for (KActionCollection *collection : qAsConst(d->actionCollections)) {
             collection->writeSettings(&group, true);
         }
     }
@@ -208,7 +210,7 @@ void KShortcutsEditor::exportConfiguration(KConfigBase *config) const
 
 void KShortcutsEditor::writeConfiguration(KConfigGroup *config) const
 {
-    foreach (KActionCollection *collection, d->actionCollections) {
+    for (KActionCollection *collection : qAsConst(d->actionCollections)) {
         collection->writeSettings(config);
     }
 }
@@ -404,20 +406,6 @@ void KShortcutsEditorPrivate::allDefault()
             changeKeyShortcut(item, GlobalAlternate, alternateSequence(defaultShortcut));
         }
 #endif
-
-#if 0
-        KShapeGesture actShapeGesture = KGestureMap::self()->shapeGesture(act);
-        KShapeGesture actDefaultShapeGesture = KGestureMap::self()->defaultShapeGesture(act);
-        if (actShapeGesture != actDefaultShapeGesture) {
-            changeShapeGesture(item, actDefaultShapeGesture);
-        }
-
-        KRockerGesture actRockerGesture = KGestureMap::self()->rockerGesture(act);
-        KRockerGesture actDefaultRockerGesture = KGestureMap::self()->defaultRockerGesture(act);
-        if (actRockerGesture != actDefaultRockerGesture) {
-            changeRockerGesture(item, actDefaultRockerGesture);
-        }
-#endif
     }
 }
 
@@ -461,13 +449,6 @@ void KShortcutsEditorPrivate::capturedShortcut(const QVariant &newShortcut, cons
     if (column >= LocalPrimary && column <= GlobalAlternate) {
         changeKeyShortcut(item, column, newShortcut.value<QKeySequence>());
     }
-#if 0
-    else if (column == ShapeGesture) {
-        changeShapeGesture(item, newShortcut.value<KShapeGesture>());
-    } else if (column == RockerGesture) {
-        changeRockerGesture(item, newShortcut.value<KRockerGesture>());
-    }
-#endif
 }
 
 void KShortcutsEditorPrivate::changeKeyShortcut(KShortcutsEditorItem *item, uint column, const QKeySequence &capture)
@@ -483,80 +464,6 @@ void KShortcutsEditorPrivate::changeKeyShortcut(KShortcutsEditorItem *item, uint
     item->setText(column, capture.toString(QKeySequence::NativeText));
 }
 
-#if 0
-void KShortcutsEditorPrivate::changeShapeGesture(KShortcutsEditorItem *item, const KShapeGesture &capture)
-{
-    if (capture == KGestureMap::self()->shapeGesture(item->m_action)) {
-        return;
-    }
-
-    if (capture.isValid()) {
-        bool conflict = false;
-        KShortcutsEditorItem *otherItem;
-
-        //search for conflicts
-        for (QTreeWidgetItemIterator it(ui.list); (*it); ++it) {
-            if (!(*it)->parent() || (*it == item)) {
-                continue;
-            }
-
-            otherItem = static_cast<KShortcutsEditorItem *>(*it);
-
-            //comparisons are possibly expensive
-            KShapeGesture otherGesture = KGestureMap::self()->shapeGesture(otherItem->m_action);
-            if (!otherGesture.isValid()) {
-                continue;
-            }
-
-            if (capture == otherGesture) {
-                conflict = true;
-                break;
-            }
-        }
-
-        if (conflict && !stealShapeGesture(otherItem, capture)) {
-            return;
-        }
-    }
-
-    item->setShapeGesture(capture);
-}
-#endif
-
-#if 0
-void KShortcutsEditorPrivate::changeRockerGesture(KShortcutsEditorItem *item, const KRockerGesture &capture)
-{
-    if (capture == KGestureMap::self()->rockerGesture(item->m_action)) {
-        return;
-    }
-
-    if (capture.isValid()) {
-        bool conflict = false;
-        KShortcutsEditorItem *otherItem;
-
-        for (QTreeWidgetItemIterator it(ui.list); (*it); ++it) {
-            if (!(*it)->parent() || (*it == item)) {
-                continue;
-            }
-
-            otherItem = static_cast<KShortcutsEditorItem *>(*it);
-
-            KRockerGesture otherGesture = KGestureMap::self()->rockerGesture(otherItem->m_action);
-            if (capture == otherGesture) {
-                conflict = true;
-                break;
-            }
-        }
-
-        if (conflict && !stealRockerGesture(otherItem, capture)) {
-            return;
-        }
-    }
-
-    item->setRockerGesture(capture);
-}
-#endif
-
 void KShortcutsEditorPrivate::clearConfiguration()
 {
     for (QTreeWidgetItemIterator it(ui.list); (*it); ++it) {
@@ -571,10 +478,6 @@ void KShortcutsEditorPrivate::clearConfiguration()
 
         changeKeyShortcut(item, GlobalPrimary,   QKeySequence());
         changeKeyShortcut(item, GlobalAlternate, QKeySequence());
-
-#if 0
-        changeShapeGesture(item, KShapeGesture());
-#endif
     }
 }
 
@@ -624,43 +527,6 @@ void KShortcutsEditorPrivate::importConfiguration(KConfigBase *config)
     }
 }
 
-#if 0
-bool KShortcutsEditorPrivate::stealShapeGesture(KShortcutsEditorItem *item, const KShapeGesture &gst)
-{
-    QString title = i18n("Key Conflict");
-    QString message = i18n("The '%1' shape gesture has already been allocated to the \"%2\" action.\n"
-                           "Do you want to reassign it from that action to the current one?",
-                           gst.shapeName(), item->m_action->text());
-
-    if (KMessageBox::warningContinueCancel(q, message, title, KGuiItem(i18n("Reassign")))
-            != KMessageBox::Continue) {
-        return false;
-    }
-    item->setShapeGesture(KShapeGesture());
-
-    return true;
-}
-#endif
-
-#if 0
-bool KShortcutsEditorPrivate::stealRockerGesture(KShortcutsEditorItem *item, const KRockerGesture &gst)
-{
-    QString title = i18n("Key Conflict");
-    QString message = i18n("The '%1' rocker gesture has already been allocated to the \"%2\" action.\n"
-                           "Do you want to reassign it from that action to the current one?",
-                           gst.rockerName(), item->m_action->text());
-
-    if (KMessageBox::warningContinueCancel(q, message, title, KGuiItem(i18n("Reassign")))
-            != KMessageBox::Continue) {
-        return false;
-    }
-
-    item->setRockerGesture(KRockerGesture());
-
-    return true;
-}
-#endif
-
 /*TODO for the printShortcuts function
 Nice to have features (which I'm not sure I can do before may due to
 more important things):
@@ -710,11 +576,12 @@ void KShortcutsEditorPrivate::printShortcuts() const
     tableformat.setBorderStyle(QTextFrameFormat::BorderStyle_Solid);
     tableformat.setBorder(0.5);
 
-    QList<QPair<QString, ColumnDesignation> > shortcutTitleToColumn;
-    shortcutTitleToColumn << qMakePair(i18n("Main:"), LocalPrimary);
-    shortcutTitleToColumn << qMakePair(i18n("Alternate:"), LocalAlternate);
-    shortcutTitleToColumn << qMakePair(i18n("Global:"), GlobalPrimary);
-    shortcutTitleToColumn << qMakePair(i18n("Global alternate:"), GlobalAlternate);
+    const QPair<QString, ColumnDesignation> shortcutTitleToColumnMap[] = {
+        qMakePair(i18n("Main:"), LocalPrimary),
+        qMakePair(i18n("Alternate:"), LocalAlternate),
+        qMakePair(i18n("Global:"), GlobalPrimary),
+        qMakePair(i18n("Global alternate:"), GlobalAlternate),
+    };
 
     for (int i = 0; i < root->childCount(); i++) {
         QTreeWidgetItem *item = root->child(i);
@@ -751,8 +618,8 @@ void KShortcutsEditorPrivate::printShortcuts() const
             table->cellAt(currow, 0).firstCursorPosition().insertText(data.toString());
 
             QTextTable *shortcutTable = nullptr;
-            for (int k = 0; k < shortcutTitleToColumn.count(); k++) {
-                data = editoritem->data(shortcutTitleToColumn.at(k).second, Qt::DisplayRole);
+            for (const auto &shortcutTitleToColumn : shortcutTitleToColumnMap) {
+                data = editoritem->data(shortcutTitleToColumn.second, Qt::DisplayRole);
                 QString key = data.value<QKeySequence>().toString();
 
                 if (!key.isEmpty()) {
@@ -766,7 +633,7 @@ void KShortcutsEditorPrivate::printShortcuts() const
                     } else {
                         shortcutTable->insertRows(shortcutTable->rows(), 1);
                     }
-                    shortcutTable->cellAt(shortcutTable->rows() - 1, 0).firstCursorPosition().insertText(shortcutTitleToColumn.at(k).first);
+                    shortcutTable->cellAt(shortcutTable->rows() - 1, 0).firstCursorPosition().insertText(shortcutTitleToColumn.first);
                     shortcutTable->cellAt(shortcutTable->rows() - 1, 1).firstCursorPosition().insertText(key);
                 }
             }
