@@ -63,14 +63,15 @@ public:
      */
     void setCheckActionCollections(const QList<KActionCollection *> &actionCollections);
 
+#if KXMLGUI_ENABLE_DEPRECATED_SINCE(4, 1)
     /**
      * @deprecated since 4.1
      * Use setCheckActionCollections so that KShortcutWidget knows
      * in which action collection to call the writeSettings method after stealing
      * a shortcut from an action.
      */
-#ifndef KXMLGUI_NO_DEPRECATED
-    KXMLGUI_DEPRECATED void setCheckActionList(const QList<QAction *> &checkList);
+    KXMLGUI_DEPRECATED_VERSION(4, 1, "Use KShortcutWidget::setCheckActionCollections(const QList<KActionCollection *> &)")
+    void setCheckActionList(const QList<QAction *> &checkList);
 #endif
 
 Q_SIGNALS:
